==> haskell-paramtree-0.1.2-24-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-paramtree.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 paramtree
version:              0.1.2
visibility:           public
id:                   paramtree-0.1.2-6UVgYknKp1DGPPEDZ0QXgQ
key:                  paramtree-0.1.2-6UVgYknKp1DGPPEDZ0QXgQ
license:              BSD-3-Clause
copyright:            Copyright © 2017-2023 Merijn Verstraaten
maintainer:           Merijn Verstraaten <merijn@inconsistent.nl>
author:               Merijn Verstraaten
homepage:             https://github.com/merijn/paramtree
synopsis:
    Generate labelled test/benchmark trees from sets of parameters

description:
    Easily generate a labelled tree of tests/benchmarks from a generation
    function and sets of parameters to use for each of that functions
    arguments. Example usecases include criterion benchmark trees or tasty test
    trees.

category:             Development, Benchmarking, Testing
abi:                  86bc60aa6f08ebba4b1ca2cfc881160f
exposed:              True
exposed-modules:      ParamTree
import-dirs:          /usr/lib/ghc-9.4.8/site-local/paramtree-0.1.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/paramtree-0.1.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/paramtree-0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-paramtree
hs-libraries:         HSparamtree-0.1.2-6UVgYknKp1DGPPEDZ0QXgQ
depends:              base-4.17.2.1 containers-0.6.7
haddock-interfaces:   /usr/share/doc/haskell-paramtree/html/paramtree.haddock
haddock-html:         /usr/share/doc/haskell-paramtree/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-paramtree-0.1.2-25-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-paramtree.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 paramtree
version:              0.1.2
visibility:           public
id:                   paramtree-0.1.2-JrDLOvqlnsK3xfAtojaKQh
key:                  paramtree-0.1.2-JrDLOvqlnsK3xfAtojaKQh
license:              BSD-3-Clause
copyright:            Copyright © 2017-2023 Merijn Verstraaten
maintainer:           Merijn Verstraaten <merijn@inconsistent.nl>
author:               Merijn Verstraaten
homepage:             https://github.com/merijn/paramtree
synopsis:
    Generate labelled test/benchmark trees from sets of parameters

description:
    Easily generate a labelled tree of tests/benchmarks from a generation
    function and sets of parameters to use for each of that functions
    arguments. Example usecases include criterion benchmark trees or tasty test
    trees.

category:             Development, Benchmarking, Testing
abi:                  5cbb8514a7040659e47b5963dd4741a0
exposed:              True
exposed-modules:      ParamTree
import-dirs:          /usr/lib/ghc-9.4.8/site-local/paramtree-0.1.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/paramtree-0.1.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/paramtree-0.1.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-paramtree
hs-libraries:         HSparamtree-0.1.2-JrDLOvqlnsK3xfAtojaKQh
depends:              base-4.17.2.1 containers-0.6.7
haddock-interfaces:   /usr/share/doc/haskell-paramtree/html/paramtree.haddock
haddock-html:         /usr/share/doc/haskell-paramtree/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
